from pysmashgg import filters
from pysmashgg.p_queries import *
from pysmashgg.api import run_query

# Shows info for a player
def show_info(player_id, header, auto_retry):
    variables = {"playerId": player_id}
    response = run_query(PLAYER_SHOW_INFO_QUERY, variables, header, auto_retry)
    data = filters.player_show_info_filter(response)
    return data

# Shows tournament attended by a player
def show_tournaments(player_id, page_num, header, auto_retry):
    variables = {"playerId": player_id, "page": page_num}
    response = run_query(PLAYER_SHOW_TOURNAMENTS_QUERY, variables, header, auto_retry)
    data = filters.player_show_tournaments_filter(response)
    return data

# Shows tournaments attended by a player for a certain game
# This is SUPER janky code but I don't know how to get it to work otherwise 
def show_tournaments_for_game(player_id, player_name, videogame_id, page_num, header, auto_retry):
    variables = {"playerId": player_id, "playerName": player_name, "videogameId": videogame_id, "page": page_num}
    response = run_query(PLAYER_SHOW_TOURNAMENTS_FOR_GAME_QUERY, variables, header, auto_retry)
    data = filters.player_show_tournaments_for_game(response, videogame_id)
    return data

# THIS WAS MADE A SEPERATE FILE TO MAKE ROOM FOR FUTURE EXPANSION


# Queries for brackets.py

BRACKET_SHOW_ENTRANTS_QUERY = """query ($phaseGroupId: ID!, $page: Int!) {
  phaseGroup(id: $phaseGroupId) {
    id
    seeds (query: {page: $page, perPage: 32}) {
      nodes {
        seedNum
        placement
        entrant {
          id
          name
          participants {
            player {
              id
              gamerTag
            }
          }
        }
      }
    }
  }
}"""

BRACKET_SHOW_SETS_QUERY = """query PhaseGroupSets($phaseGroupId: ID!, $page:Int!){
  phaseGroup(id:$phaseGroupId){
    phase {
      name
    }
    sets(
      page: $page
      perPage: 32
    ){
      nodes{
        id
        slots{
          entrant{
            id
            name
            participants {
              player {
                id
                gamerTag
              }
            }
          }
          standing {
            placement
            stats {
              score {
                value
              }
            }
          }
        }
      }
    }
  }
}"""



from pysmashgg import filters
from pysmashgg.l_queries import *
from pysmashgg.api import run_query

# Shows metadata for a league
def show(league_name, header, auto_retry):
    variables = {"slug": league_name}
    response = run_query(SHOW_QUERY, variables, header, auto_retry)
    data = filters.league_show_filter(response)
    return data

# Shows schedule for a league
def show_schedule(league_name, page_num, header, auto_retry):
    variables = {"slug": league_name, "page": page_num}
    response = run_query(SHOW_SCHEDULE_QUERY, variables, header, auto_retry)
    data = filters.league_show_schedule_filter(response)
    return data

# Shows standings for a league
def show_standings(league_name, page_num, header, auto_retry):
    variables = {"slug": league_name, "page": page_num}
    response = run_query(SHOW_STANDINGS_QUERY, variables, header, auto_retry)
    data = filters.league_show_standings_filter(response)
    return data

# THIS WAS MADE A SEPERATE FILE TO MAKE ROOM FOR FUTURE EXPANSION


# Queries for events.py

ENTRANT_ID_QUERY = """query EventEntrants($eventId: ID!, $name: String!) {
    event(id: $eventId) {
    entrants(query: {
      page: 1
      perPage: 32
      filter: {
        name: $name
      }
    }) {
      nodes {
        id
        name
      }
    }
    }
    }"""


SHOW_SETS_QUERY = """query EventSets($eventId: ID!, $page: Int!) {
  event(id: $eventId) {
    tournament {
      id
      name
    }
    name
    sets(page: $page, perPage: 18, sortType: STANDARD) {
      nodes {
        games {
          winnerId
          selections {
            selectionValue
          }
        }
        id
        slots {
          standing {
            id
            placement
            stats {
              score {
                value
              }
            }
          }
          entrant {
            id
            name
            participants {
              entrants {
                id
              }
              player {
                id
                gamerTag
                
              }
            }
          }
        }
        phaseGroup {
          id
          phase {
            name
          }
        }
      }
    }
  }
}"""


SHOW_ENTRANTS_QUERY = """query EventStandings($eventId: ID!, $page: Int!) {
  event(id: $eventId) {
    id
    name
    standings(query: {
      perPage: 25,
      page: $page}){
      nodes {
        placement
        entrant {
          id
          name
          participants {
            player {
              id
              gamerTag
            }
          }
          seeds {
            seedNum
          }
        }
      }
    }
  }
}"""

SHOW_ENTRANT_SETS_QUERY = """query EventSets($eventId: ID!, $entrantId: ID!, $page: Int!) {
  event(id: $eventId) {
    sets(
      page: $page
      perPage: 16
      filters: {
        entrantIds: [$entrantId]
      }
    ) {
      nodes {
        id
        fullRoundText
        slots {
          standing {
            placement
            stats {
              score {
                value
              }
            }
          }
          entrant {
            id
            name
          }
        }
        phaseGroup {
          id
        }
      }
    }
  }
}"""

SHOW_LIGHTWEIGHT_RESULTS_QUERY = """query EventStandings($eventId: ID!, $page: Int!,) {
  event(id: $eventId) {
    standings(query: {
      perPage: 64,
      page: $page
    }){
      nodes {
        placement
        entrant {
          name
          id
        }
      }
    }
  }
}"""